@@ -5,7 +5,7 @@ BEGIN {
   $MojoX::Renderer::Alloy::AUTHORITY = 'cpan:AJGB';
 }
 BEGIN {
-  $MojoX::Renderer::Alloy::VERSION = '1.110180';
+  $MojoX::Renderer::Alloy::VERSION = '1.112200';
 }
 #ABSTRACT: Base class for Template::Alloy renderer
 
@@ -75,7 +75,7 @@ sub _get_input {
             $path # regular file
             :
             do { # inlined templates are not supported
-                if ( $r->get_inline_template($options, $tname) ) {
+                if ( $r->get_data_template($options, $tname) ) {
                     $c->render_exception(
                         "Inlined templates are not supported"
                     );
@@ -86,8 +86,51 @@ sub _get_input {
             };
 };
 
+sub _template_vars {
+    my ($self, $c) = @_;
+
+    my $helper = MojoX::Renderer::Alloy::Helper->new(ctx => $c);
+
+    # allows to overwrite "h"
+    return {
+        h => $helper,
+        %{ $c->stash },
+        c => $c,
+    },
+}
+
+# stolen from MojoX::Renderer::TT
+package
+  MojoX::Renderer::Alloy::Helper;
+
+use strict;
+use warnings;
+
+use base 'Mojo::Base';
+
+our $AUTOLOAD;
+
+__PACKAGE__->attr('ctx');
+
+sub AUTOLOAD {
+    my $self = shift;
+
+    my $method = $AUTOLOAD;
+
+    return if $method =~ /^[A-Z]+?$/;
+    return if $method =~ /^_/;
+    return if $method =~ /(?:\:*?)DESTROY$/;
+
+    $method = (split '::' => $method)[-1];
+
+    die qq/Unknown helper: $method/ unless $self->ctx->app->renderer->helpers->{$method};
+
+    return $self->ctx->$method(@_);
+}
+
 1;
 
+
 __END__
 =pod
 
@@ -99,7 +142,7 @@ MojoX::Renderer::Alloy - Base class for Template::Alloy renderer
 
 =head1 VERSION
 
-version 1.110180
+version 1.112200
 
 =head1 SYNOPSIS
 
@@ -123,7 +166,8 @@ Base abstract class for following renderers:
 
 Build handler for selected renderer.
 
-Please note that for all renderers a L<Mojolicious::Controller> is available as C<c> variable.
+Please note that for all renderers a L<Mojolicious::Controller> is available
+as C<c> variable, while helpers are available as C<h> variable.
 
 =head1 AUTHOR
 
