@@ -5,7 +5,7 @@ BEGIN {
   $MojoX::Renderer::Alloy::Tmpl::AUTHORITY = 'cpan:AJGB';
 }
 BEGIN {
-  $MojoX::Renderer::Alloy::Tmpl::VERSION = '1.110180';
+  $MojoX::Renderer::Alloy::Tmpl::VERSION = '1.112200';
 }
 #ABSTRACT: Template::Alloy's Text::Tmpl renderer
 
@@ -58,7 +58,7 @@ sub _render {
         $method = 'parse_file';
     } else {
         # inlined templates are not supported
-        if ( $r->get_inline_template($options, $tname) ) {
+        if ( $r->get_data_template($options, $tname) ) {
             $c->render_exception(
                 "Inlined templates are not supported"
             );
@@ -70,10 +70,7 @@ sub _render {
 
     my $alloy = $self->alloy;
     $alloy->set_values(
-        {
-            %{ $c->stash },
-            c => $c,
-        },
+        $self->_template_vars( $c )
     );
 
     eval {
@@ -102,7 +99,7 @@ MojoX::Renderer::Alloy::Tmpl - Template::Alloy's Text::Tmpl renderer
 
 =head1 VERSION
 
-version 1.110180
+version 1.112200
 
 =head1 SYNOPSIS
 
@@ -124,7 +121,7 @@ Mojolicious::Lite
 
 =head1 DESCRIPTION
 
-    <a href="#[ echo c.url_for('about_us') ]#">Hello!</a>
+    <a href="#[ echo h.url_for('about_us') ]#">Hello!</a>
 
     #[include "include.inc"]#
 
